import * as PropTypes from 'prop-types';
import * as React from 'react';
import { useDebugValue, useEffect, useMemo, useState } from 'react';
import { executeMediaQuery, Media } from './Media';
import { getMaxMatch, inBetween, nothingSet, notNulls, pickMatchValues, pickMediaMatch, pickMediaMatchSlot, } from './utils';
const castPointsTo = (points, targetType) => Object.keys(points).reduce((acc, key) => {
    acc[key] = targetType;
    return acc;
}, {});
const skipProp = {};
// @ts-ignore
const use = (...args) => null;
export function createMediaMatcher(queries, firstKey) {
    use(firstKey);
    const mediaDefaults = executeMediaQuery(queries);
    const initialValue = {};
    const MediaContext = React.createContext(initialValue);
    const getMediaMatches = (matches) => (matches === initialValue ? mediaDefaults : matches);
    const consume = (cb) => (React.createElement(MediaContext.Consumer, null, (matched) => cb(getMediaMatches(matched))));
    function pickMatch(matches, slots, defaultValue) {
        return pickMediaMatch(queries, matches, slots, defaultValue);
    }
    function useMedia(slots, defaultValue) {
        const matches = getMediaMatches(React.useContext(MediaContext));
        if (process.env.NODE_ENV !== 'production') {
            // eslint-disable-next-line react-hooks/rules-of-hooks
            useDebugValue(pickMediaMatchSlot(queries, matches, slots) || 'default');
        }
        return pickMatch(matches, slots, defaultValue);
    }
    function pickMatchEx(matches, slots) {
        return pickMediaMatch(queries, matches, slots);
    }
    const ProvideMediaMatchers = ({ children, state = null }) => (React.createElement(MediaContext.Consumer, null, (parentMatch) => (React.createElement(Media, { queries: queries }, (matches) => {
        const value = state || {
            ...(parentMatch || {}),
            ...notNulls(matches),
        };
        return React.createElement(MediaContext.Provider, { value: value, children: children });
    }))));
    ProvideMediaMatchers.propTypes =
        // @ts-ignore
        process.env.NODE_ENV !== 'production'
            ? {
                state: PropTypes.shape({
                    ...castPointsTo(queries, PropTypes.bool),
                }),
            }
            : skipProp;
    const MediaMatches = ({ children }) => consume((matched) => children(matched, (matches) => pickMatch(matched, matches)));
    MediaMatches.propTypes =
        // @ts-ignore
        process.env.NODE_ENV !== 'production'
            ? {
                children: PropTypes.func.isRequired,
            }
            : skipProp;
    const InlineMediaMatcher = (props) => consume((matched) => pickMatchEx(matched, props));
    const MediaMatcher = (props) => consume((matched) => pickMatchEx(matched, props));
    MediaMatcher.propTypes =
        // @ts-ignore
        process.env.NODE_ENV !== 'production'
            ? {
                ...castPointsTo(queries, PropTypes.node),
            }
            : skipProp;
    const Mock = ({ children, ...props }) => (React.createElement(MediaContext.Provider, { value: pickMatchValues(queries, { ...nothingSet(queries), ...props }) }, children));
    const Override = ({ children, ...props }) => (React.createElement(MediaContext.Consumer, null, (parentMatch) => {
        const value = {
            ...notNulls(parentMatch),
            ...pickMatchValues(queries, props),
        };
        return React.createElement(MediaContext.Provider, { value: value, children: children });
    }));
    const Below = ({ children, including, ...props }) => React.createElement(MediaMatcher, { ...inBetween(queries, props, children, !including, true) });
    const Above = ({ children, including, ...props }) => React.createElement(MediaMatcher, { ...inBetween(queries, props, children, !!including, false) });
    const MediaServerSide = ({ predicted, hydrated, onWrongPrediction, children }) => {
        const [isHydrated, setHydrated] = useState(hydrated === undefined ? false : hydrated);
        const media = React.useContext(MediaContext);
        useEffect(() => {
            setHydrated(hydrated === undefined ? true : hydrated);
        }, [hydrated]);
        useEffect(() => {
            if (isHydrated && !media[predicted]) {
                if (onWrongPrediction) {
                    onWrongPrediction(predicted, getMaxMatch(queries, media));
                }
            }
        }, [isHydrated]);
        const overrides = useMemo(() => {
            if (isHydrated) {
                return media;
            }
            else {
                return {
                    ...nothingSet(queries),
                    [predicted]: true,
                };
            }
        }, [media, isHydrated]);
        return React.createElement(MediaContext.Provider, { value: overrides, children: children });
    };
    const ServerRender = ({ predicted, hydrated, onWrongPrediction, children }) => (React.createElement(ProvideMediaMatchers, null,
        React.createElement(MediaServerSide, { predicted: predicted, hydrated: hydrated, onWrongPrediction: onWrongPrediction, children: children })));
    return {
        queries,
        pickMatch,
        useMedia,
        Provider: ProvideMediaMatchers,
        Mock,
        Override,
        //
        Matches: MediaMatches,
        Inline: InlineMediaMatcher,
        Above,
        Below,
        //
        Matcher: MediaMatcher,
        ServerRender,
        //
        Gearbox: MediaContext.Consumer,
        Consumer: MediaContext.Consumer,
    };
}
