export function forEachName(object, map) {
    return Object.keys(object)
        .map((key) => ({ key, value: map(key) }))
        .reduce((acc, line) => ({
        ...acc,
        [line.key]: line.value,
    }), {});
}
export function getMaxMatch(mediaRules, matches) {
    const keys = Object.keys(mediaRules);
    const len = keys.length;
    let index = 0;
    for (; index < len; index++) {
        if (matches[keys[index]]) {
            break;
        }
    }
    return keys[index];
}
function validateSlots(rules, slots) {
    if (
    // @ts-ignore
    process.env.NODE_ENV !== 'production') {
        // validate slots versus rules
        Object.keys(slots).forEach((slotKey) => {
            if (rules.indexOf(slotKey) < 0) {
                throw new Error('react-media-match: used slot [' +
                    slotKey +
                    '] is not among [' +
                    rules.join(',') +
                    ']. This is a development error only');
            }
        });
    }
}
export function pickMediaMatchSlot(mediaRules, matches, slots) {
    const keys = Object.keys(mediaRules);
    const len = keys.length;
    validateSlots(keys, slots);
    let index = 0;
    for (; index < len; index++) {
        if (matches[keys[index]]) {
            break;
        }
    }
    for (; index >= 0; index--) {
        const value = slots[keys[index]];
        if (value !== undefined) {
            return keys[index];
        }
    }
    return undefined;
}
export function pickMediaMatch(mediaRules, matches, slots, defaultValue) {
    const keys = Object.keys(mediaRules);
    const len = keys.length;
    validateSlots(keys, slots);
    let index = 0;
    for (; index < len; index++) {
        if (matches[keys[index]]) {
            break;
        }
    }
    for (; index >= 0; index--) {
        const value = slots[keys[index]];
        if (value !== undefined) {
            return value;
        }
    }
    // could be only possible if no slots is given, so K is undefined
    return defaultValue;
}
export function pickMatchValues(points, props) {
    const keys = Object.keys(points);
    validateSlots(keys, props);
    return keys.reduce((acc, key) => {
        if (props[key] !== undefined) {
            acc[key] = props[key];
        }
        return acc;
    }, {});
}
export function inBetween(breakPoints, points, value, invert, include) {
    const keys = Object.keys(breakPoints);
    let pass = false;
    validateSlots(keys, points);
    return Object.keys(breakPoints).reduce((acc, key) => {
        if (invert && points[key]) {
            pass = true;
        }
        acc[key] = (include ? pass : !pass) ? null : value;
        if (!invert && points[key]) {
            pass = true;
        }
        return acc;
    }, {});
}
export function nothingSet(matches) {
    return Object.keys(matches).reduce((acc, key) => {
        acc[key] = false;
        return acc;
    }, {});
}
export function notNulls(matches) {
    return Object.keys(matches).reduce((acc, key) => {
        if (matches[key] !== undefined) {
            acc[key] = matches[key];
        }
        return acc;
    }, {});
}
