/**
 * bootstrap breakpoints (max-width)
 * - xxs, extra-extra-small: 0px, a virtual starting point
 * - xs, extra-small: 359px, the end of "small" phones
 * - sm, small: 600px, theoretical start of tablets
 * - md, medium: 960px, theoretical start of desktops
 * - lg, large: 1280px, a normal desktop
 * - xl, extra-large: 1920px, wide desktops
 * @see https://material-ui.com/customization/breakpoints/
 */
export declare const breakpoints: import("./types").MediaMatcherType<{
    xxs: unknown;
    xs: unknown;
    sm: unknown;
    md: unknown;
    lg: unknown;
    xl: unknown;
}, "xxs">;
/**
 * device orientation (orientation)
 * - portrait
 * - landscape
 * @see https://developer.mozilla.org/en-US/docs/Web/CSS/@media/orientation
 */
export declare const orientation: import("./types").MediaMatcherType<{
    portrait: unknown;
    landscape: unknown;
}, "portrait">;
/**
 * hover capabilities (hover)
 * - incapable (touchDevice)
 * - capable (mouseDevice)
 * @see https://developer.mozilla.org/en-US/docs/Web/CSS/@media/hover
 */
export declare const hover: import("./types").MediaMatcherType<{
    incapable: unknown;
    capable: unknown;
}, "incapable">;
/**
 * dark mode (prefers-color-scheme)
 * - light
 * - dark
 * @see https://developer.mozilla.org/en-US/docs/Web/CSS/@media/prefers-color-scheme
 */
export declare const darkMode: import("./types").MediaMatcherType<{
    light: unknown;
    dark: unknown;
}, "light">;
/**
 * reduced motion (prefers-reduced-motion)
 * - normal
 * - reduce
 * @see https://developer.mozilla.org/en-US/docs/Web/CSS/@media/prefers-reduced-motion
 */
export declare const reducedMotion: import("./types").MediaMatcherType<{
    normal: unknown;
    reduced: unknown;
}, "normal">;
