"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reducedMotion = exports.darkMode = exports.hover = exports.orientation = exports.breakpoints = void 0;
var createMediaMatcher_1 = require("./createMediaMatcher");
/**
 * bootstrap breakpoints (max-width)
 * - xxs, extra-extra-small: 0px, a virtual starting point
 * - xs, extra-small: 359px, the end of "small" phones
 * - sm, small: 600px, theoretical start of tablets
 * - md, medium: 960px, theoretical start of desktops
 * - lg, large: 1280px, a normal desktop
 * - xl, extra-large: 1920px, wide desktops
 * @see https://material-ui.com/customization/breakpoints/
 */
exports.breakpoints = (0, createMediaMatcher_1.createMediaMatcher)({
    xxs: '(max-width: 359px)',
    xs: '(max-width: 599px)',
    sm: '(max-width: 959px)',
    md: '(max-width: 1279px)',
    lg: '(max-width: 1919px)',
    xl: '(min-width: 1920px)',
}, 'xxs');
/**
 * device orientation (orientation)
 * - portrait
 * - landscape
 * @see https://developer.mozilla.org/en-US/docs/Web/CSS/@media/orientation
 */
exports.orientation = (0, createMediaMatcher_1.createMediaMatcher)({
    portrait: '(orientation: portrait)',
    landscape: '(orientation: landscape)',
}, 'portrait');
/**
 * hover capabilities (hover)
 * - incapable (touchDevice)
 * - capable (mouseDevice)
 * @see https://developer.mozilla.org/en-US/docs/Web/CSS/@media/hover
 */
exports.hover = (0, createMediaMatcher_1.createMediaMatcher)({
    incapable: '(hover: none)',
    capable: '(hover: hover)',
}, 'incapable');
/**
 * dark mode (prefers-color-scheme)
 * - light
 * - dark
 * @see https://developer.mozilla.org/en-US/docs/Web/CSS/@media/prefers-color-scheme
 */
exports.darkMode = (0, createMediaMatcher_1.createMediaMatcher)({
    light: true,
    dark: '(prefers-color-scheme: dark)',
}, 'light');
/**
 * reduced motion (prefers-reduced-motion)
 * - normal
 * - reduce
 * @see https://developer.mozilla.org/en-US/docs/Web/CSS/@media/prefers-reduced-motion
 */
exports.reducedMotion = (0, createMediaMatcher_1.createMediaMatcher)({
    normal: true,
    reduced: '(prefers-reduced-motion: reduce)',
}, 'normal');
